<?php $TRANSLATIONS = array(
"OpenID Changed" => "OpenID 改变了",
"Invalid request" => "非法请求",
"This is an OpenID server endpoint. For more information, see " => "这是一个 OpenID 服务器终端。详情参考",
"Identity: <b>" => "身份：<b>",
"Realm: <b>" => "领域：<b>",
"User: <b>" => "用户：<b>",
"Login" => "登录",
"Error: <b>No user Selected" => "出错：<b>未选择用户",
"you can authenticate to other sites with this address" => "您可以使用此地址验证其他站点",
"Authorized OpenID provider" => "验证的 OpenID 提供商",
"Your address at Wordpress, Identi.ca, &hellip;" => "你在 Wordpress，Identi.ca，&hellip 的地址;"
);
